Crate dear_implot_sys

Crate dear_implot_sys 

Low-level FFI bindings for ImPlot via the cimplot C API

This crate provides raw, unsafe bindings to the ImPlot library using the cimplot C API, designed to work together with dear-imgui-sys (which uses cimgui for Dear ImGui). This avoids C++ ABI issues and keeps builds consistent across platforms and toolchains.

Features

  • docking: Enable docking and multi-viewport features (default)
  • freetype: Enable FreeType font rasterizer support
  • wasm: Enable WebAssembly compatibility

Safety

This crate provides raw FFI bindings and is inherently unsafe. Users should prefer the high-level dear-implot crate for safe Rust bindings.

Usage

This crate is typically not used directly. Instead, use the dear-implot crate which provides safe, idiomatic Rust bindings built on top of these FFI bindings.

Structs

ImBitArray_ImGuiKey_NamedKey_COUNT__lessImGuiKey_NamedKey_BEGIN
ImChunkStream_ImGuiTableSettings
ImChunkStream_ImGuiWindowSettings
ImDrawChannel
ImDrawCmd
ImDrawCmdHeader
ImDrawData
ImDrawDataBuilder
ImDrawList
ImDrawListSharedData
ImDrawListSplitter
ImDrawVert
ImFont
ImFontAtlas
ImFontAtlasBuilder
ImFontAtlasRectEntry
ImFontBaked
ImFontConfig
ImFontGlyph
ImFontLoader
ImFontStackData
ImGuiBoxSelectState
ImGuiColorMod
ImGuiComboPreviewData
ImGuiContext
ImGuiContextHook
ImGuiDataTypeStorage
ImGuiDeactivatedItemData
ImGuiDebugAllocEntry
ImGuiDebugAllocInfo
ImGuiDebugItemPathQuery
ImGuiDockContext
ImGuiDockNode
ImGuiDockNodeSettings
ImGuiDockRequest
ImGuiErrorRecoveryState
ImGuiFocusScopeData
ImGuiGroupData
ImGuiIDStackTool
ImGuiIO
ImGuiInputEvent
ImGuiInputEventAppFocused
ImGuiInputEventKey
ImGuiInputEventMouseButton
ImGuiInputEventMousePos
ImGuiInputEventMouseViewport
ImGuiInputEventMouseWheel
ImGuiInputEventText
ImGuiInputTextDeactivatedState
ImGuiInputTextState
ImGuiKeyData
ImGuiKeyOwnerData
ImGuiKeyRoutingData
ImGuiKeyRoutingTable
ImGuiLastItemData
ImGuiListClipper
ImGuiListClipperData
ImGuiListClipperRange
ImGuiMenuColumns
ImGuiMetricsConfig
ImGuiMultiSelectIO
ImGuiMultiSelectState
ImGuiMultiSelectTempData
ImGuiNavItemData
ImGuiNextItemData
ImGuiNextWindowData
ImGuiOldColumnData
ImGuiOldColumns
ImGuiPackedDate
ImGuiPayload
ImGuiPlatformIO
ImGuiPlatformImeData
ImGuiPlatformMonitor
ImGuiPopupData
ImGuiPtrOrIndex
ImGuiSelectionRequest
ImGuiSettingsHandler
ImGuiShrinkWidthItem
ImGuiSizeCallbackData
ImGuiStackLevelInfo
ImGuiStorage
ImGuiStoragePair
ImGuiStyle
ImGuiStyleMod
ImGuiTabBar
ImGuiTabItem
ImGuiTable
ImGuiTableCellData
ImGuiTableColumn
ImGuiTableColumnSortSpecs
ImGuiTableHeaderData
ImGuiTableInstanceData
ImGuiTableReconcileColumnData
ImGuiTableSortSpecs
ImGuiTableTempData
ImGuiTextBuffer
ImGuiTextIndex
ImGuiTreeNodeStackData
ImGuiTypingSelectRequest
ImGuiTypingSelectState
ImGuiViewport
ImGuiViewportP
ImGuiWindow
ImGuiWindowClass
ImGuiWindowDockStyle
ImGuiWindowStackData
ImGuiWindowTempData
ImPlotAlignmentData
ImPlotAnnotation
ImPlotAnnotationCollection
ImPlotAxisColor
ImPlotAxis_c
ImPlotColormapData
ImPlotContext
ImPlotDateTimeSpec_c
ImPlotInputMap
ImPlotItem
ImPlotItemGroup
ImPlotLegend
ImPlotNextItemData
ImPlotNextPlotData
ImPlotPlot
ImPlotPointError
ImPlotPoint_c
ImPlotRange_c
ImPlotRect_c
ImPlotSpec_c
ImPlotStyle
ImPlotSubplot
ImPlotTag
ImPlotTagCollection
ImPlotTick_c
ImPlotTicker
ImPlotTime_c
ImPool_ImGuiMultiSelectState
ImPool_ImGuiTabBar
ImPool_ImGuiTable
ImPool_ImPlotAlignmentData
ImPool_ImPlotItem
ImPool_ImPlotPlot
ImPool_ImPlotSubplot
ImRect_c
ImSpan_ImGuiTableCellData
ImSpan_ImGuiTableColumn
ImSpan_ImGuiTableColumnIdx
ImStableVector_ImFontBaked__32
ImTextureData
ImTextureRect
ImTextureRef_c
ImVec1
ImVec2_c
ImVec2i_c
ImVec2ih
ImVec4_c
ImVector_ImDrawChannel
ImVector_ImDrawCmd
ImVector_ImDrawIdx
ImVector_ImDrawListPtr
ImVector_ImDrawListSharedDataPtr
ImVector_ImDrawVert
ImVector_ImFontAtlasPtr
ImVector_ImFontAtlasRectEntry
ImVector_ImFontBakedPtr
ImVector_ImFontConfig
ImVector_ImFontConfigPtr
ImVector_ImFontGlyph
ImVector_ImFontPtr
ImVector_ImFontStackData
ImVector_ImGuiColorMod
ImVector_ImGuiContextHook
ImVector_ImGuiDockNodeSettings
ImVector_ImGuiDockRequest
ImVector_ImGuiFocusScopeData
ImVector_ImGuiGroupData
ImVector_ImGuiID
ImVector_ImGuiInputEvent
ImVector_ImGuiItemFlags
ImVector_ImGuiKeyRoutingData
ImVector_ImGuiListClipperData
ImVector_ImGuiListClipperRange
ImVector_ImGuiMultiSelectState
ImVector_ImGuiMultiSelectTempData
ImVector_ImGuiOldColumnData
ImVector_ImGuiOldColumns
ImVector_ImGuiPlatformMonitor
ImVector_ImGuiPopupData
ImVector_ImGuiPtrOrIndex
ImVector_ImGuiSelectionRequest
ImVector_ImGuiSettingsHandler
ImVector_ImGuiShrinkWidthItem
ImVector_ImGuiStackLevelInfo
ImVector_ImGuiStoragePair
ImVector_ImGuiStyleMod
ImVector_ImGuiTabBar
ImVector_ImGuiTabItem
ImVector_ImGuiTable
ImVector_ImGuiTableColumnSortSpecs
ImVector_ImGuiTableHeaderData
ImVector_ImGuiTableInstanceData
ImVector_ImGuiTableReconcileColumnData
ImVector_ImGuiTableTempData
ImVector_ImGuiTreeNodeStackData
ImVector_ImGuiViewportPPtr
ImVector_ImGuiViewportPtr
ImVector_ImGuiWindowPtr
ImVector_ImGuiWindowStackData
ImVector_ImPlotAlignmentData
ImVector_ImPlotAnnotation
ImVector_ImPlotColormap
ImVector_ImPlotItem
ImVector_ImPlotPlot
ImVector_ImPlotRange
ImVector_ImPlotSubplot
ImVector_ImPlotTag
ImVector_ImPlotTick
ImVector_ImS8
ImVector_ImS16
ImVector_ImS32
ImVector_ImS64
ImVector_ImTextureDataPtr
ImVector_ImTextureRect
ImVector_ImTextureRef
ImVector_ImU8
ImVector_ImU16
ImVector_ImU32
ImVector_ImU64
ImVector_ImVec2
ImVector_ImVec4
ImVector_ImWchar
ImVector_bool
ImVector_char
ImVector_double
ImVector_float
ImVector_int
ImVector_stbrp_node_im
ImVector_unsigned_char
STB_TexteditState
StbUndoRecord
StbUndoState
__BindgenBitfieldUnit
stbrp_context_opaque
stbrp_node
tm

Constants

IMPLOT_AUTO
IMPLOT_LABEL_MAX_SIZE
IMPLOT_MAX_TIME
IMPLOT_MIN_TIME
ImGuiAxis_None
ImGuiAxis_X
ImGuiAxis_Y
ImGuiContextHookType_EndFramePost
ImGuiContextHookType_EndFramePre
ImGuiContextHookType_NewFramePost
ImGuiContextHookType_NewFramePre
ImGuiContextHookType_PendingRemoval_
ImGuiContextHookType_RenderPost
ImGuiContextHookType_RenderPre
ImGuiContextHookType_Shutdown
ImGuiDir_COUNT
ImGuiDir_Down
ImGuiDir_Left
ImGuiDir_None
ImGuiDir_Right
ImGuiDir_Up
ImGuiDockNodeState_HostWindowHiddenBecauseSingleWindow
ImGuiDockNodeState_HostWindowHiddenBecauseWindowsAreResizing
ImGuiDockNodeState_HostWindowVisible
ImGuiDockNodeState_Unknown
ImGuiInputEventType_COUNT
ImGuiInputEventType_Focus
ImGuiInputEventType_Key
ImGuiInputEventType_MouseButton
ImGuiInputEventType_MousePos
ImGuiInputEventType_MouseViewport
ImGuiInputEventType_MouseWheel
ImGuiInputEventType_None
ImGuiInputEventType_Text
ImGuiInputSource_COUNT
ImGuiInputSource_Gamepad
ImGuiInputSource_Keyboard
ImGuiInputSource_Mouse
ImGuiInputSource_None
ImGuiKey_0
ImGuiKey_1
ImGuiKey_2
ImGuiKey_3
ImGuiKey_4
ImGuiKey_5
ImGuiKey_6
ImGuiKey_7
ImGuiKey_8
ImGuiKey_9
ImGuiKey_A
ImGuiKey_Apostrophe
ImGuiKey_AppBack
ImGuiKey_AppForward
ImGuiKey_B
ImGuiKey_Backslash
ImGuiKey_Backspace
ImGuiKey_C
ImGuiKey_CapsLock
ImGuiKey_Comma
ImGuiKey_D
ImGuiKey_Delete
ImGuiKey_DownArrow
ImGuiKey_E
ImGuiKey_End
ImGuiKey_Enter
ImGuiKey_Equal
ImGuiKey_Escape
ImGuiKey_F
ImGuiKey_F1
ImGuiKey_F2
ImGuiKey_F3
ImGuiKey_F4
ImGuiKey_F5
ImGuiKey_F6
ImGuiKey_F7
ImGuiKey_F8
ImGuiKey_F9
ImGuiKey_F10
ImGuiKey_F11
ImGuiKey_F12
ImGuiKey_F13
ImGuiKey_F14
ImGuiKey_F15
ImGuiKey_F16
ImGuiKey_F17
ImGuiKey_F18
ImGuiKey_F19
ImGuiKey_F20
ImGuiKey_F21
ImGuiKey_F22
ImGuiKey_F23
ImGuiKey_F24
ImGuiKey_G
ImGuiKey_GamepadBack
ImGuiKey_GamepadDpadDown
ImGuiKey_GamepadDpadLeft
ImGuiKey_GamepadDpadRight
ImGuiKey_GamepadDpadUp
ImGuiKey_GamepadFaceDown
ImGuiKey_GamepadFaceLeft
ImGuiKey_GamepadFaceRight
ImGuiKey_GamepadFaceUp
ImGuiKey_GamepadL1
ImGuiKey_GamepadL2
ImGuiKey_GamepadL3
ImGuiKey_GamepadLStickDown
ImGuiKey_GamepadLStickLeft
ImGuiKey_GamepadLStickRight
ImGuiKey_GamepadLStickUp
ImGuiKey_GamepadR1
ImGuiKey_GamepadR2
ImGuiKey_GamepadR3
ImGuiKey_GamepadRStickDown
ImGuiKey_GamepadRStickLeft
ImGuiKey_GamepadRStickRight
ImGuiKey_GamepadRStickUp
ImGuiKey_GamepadStart
ImGuiKey_GraveAccent
ImGuiKey_H
ImGuiKey_Home
ImGuiKey_I
ImGuiKey_Insert
ImGuiKey_J
ImGuiKey_K
ImGuiKey_Keypad0
ImGuiKey_Keypad1
ImGuiKey_Keypad2
ImGuiKey_Keypad3
ImGuiKey_Keypad4
ImGuiKey_Keypad5
ImGuiKey_Keypad6
ImGuiKey_Keypad7
ImGuiKey_Keypad8
ImGuiKey_Keypad9
ImGuiKey_KeypadAdd
ImGuiKey_KeypadDecimal
ImGuiKey_KeypadDivide
ImGuiKey_KeypadEnter
ImGuiKey_KeypadEqual
ImGuiKey_KeypadMultiply
ImGuiKey_KeypadSubtract
ImGuiKey_L
ImGuiKey_LeftAlt
ImGuiKey_LeftArrow
ImGuiKey_LeftBracket
ImGuiKey_LeftCtrl
ImGuiKey_LeftShift
ImGuiKey_LeftSuper
ImGuiKey_M
ImGuiKey_Menu
ImGuiKey_Minus
ImGuiKey_MouseLeft
ImGuiKey_MouseMiddle
ImGuiKey_MouseRight
ImGuiKey_MouseWheelX
ImGuiKey_MouseWheelY
ImGuiKey_MouseX1
ImGuiKey_MouseX2
ImGuiKey_N
ImGuiKey_NamedKey_BEGIN
ImGuiKey_NamedKey_COUNT
ImGuiKey_NamedKey_END
ImGuiKey_None
ImGuiKey_NumLock
ImGuiKey_O
ImGuiKey_Oem102
ImGuiKey_P
ImGuiKey_PageDown
ImGuiKey_PageUp
ImGuiKey_Pause
ImGuiKey_Period
ImGuiKey_PrintScreen
ImGuiKey_Q
ImGuiKey_R
ImGuiKey_ReservedForModAlt
ImGuiKey_ReservedForModCtrl
ImGuiKey_ReservedForModShift
ImGuiKey_ReservedForModSuper
ImGuiKey_RightAlt
ImGuiKey_RightArrow
ImGuiKey_RightBracket
ImGuiKey_RightCtrl
ImGuiKey_RightShift
ImGuiKey_RightSuper
ImGuiKey_S
ImGuiKey_ScrollLock
ImGuiKey_Semicolon
ImGuiKey_Slash
ImGuiKey_Space
ImGuiKey_T
ImGuiKey_Tab
ImGuiKey_U
ImGuiKey_UpArrow
ImGuiKey_V
ImGuiKey_W
ImGuiKey_X
ImGuiKey_Y
ImGuiKey_Z
ImGuiMod_Alt
ImGuiMod_Ctrl
ImGuiMod_Mask_
ImGuiMod_None
ImGuiMod_Shift
ImGuiMod_Super
ImGuiMouseSource_COUNT
ImGuiMouseSource_Mouse
ImGuiMouseSource_Pen
ImGuiMouseSource_TouchScreen
ImGuiNavLayer_COUNT
ImGuiNavLayer_Main
ImGuiNavLayer_Menu
ImGuiSelectionRequestType_None
ImGuiSelectionRequestType_SetAll
ImGuiSelectionRequestType_SetRange
ImGuiSortDirection_Ascending
ImGuiSortDirection_Descending
ImGuiSortDirection_None
ImPlotAxisFlags_AutoFit
ImPlotAxisFlags_AuxDefault
ImPlotAxisFlags_Foreground
ImPlotAxisFlags_Invert
ImPlotAxisFlags_Lock
ImPlotAxisFlags_LockMax
ImPlotAxisFlags_LockMin
ImPlotAxisFlags_NoDecorations
ImPlotAxisFlags_NoGridLines
ImPlotAxisFlags_NoHighlight
ImPlotAxisFlags_NoInitialFit
ImPlotAxisFlags_NoLabel
ImPlotAxisFlags_NoMenus
ImPlotAxisFlags_NoSideSwitch
ImPlotAxisFlags_NoTickLabels
ImPlotAxisFlags_NoTickMarks
ImPlotAxisFlags_None
ImPlotAxisFlags_Opposite
ImPlotAxisFlags_PanStretch
ImPlotAxisFlags_RangeFit
ImPlotBarGroupsFlags_Horizontal
ImPlotBarGroupsFlags_None
ImPlotBarGroupsFlags_Stacked
ImPlotBarsFlags_Horizontal
ImPlotBarsFlags_None
ImPlotBin_Rice
ImPlotBin_Scott
ImPlotBin_Sqrt
ImPlotBin_Sturges
ImPlotBubblesFlags_None
ImPlotCol_AxisBg
ImPlotCol_AxisBgActive
ImPlotCol_AxisBgHovered
ImPlotCol_AxisGrid
ImPlotCol_AxisText
ImPlotCol_AxisTick
ImPlotCol_COUNT
ImPlotCol_Crosshairs
ImPlotCol_FrameBg
ImPlotCol_InlayText
ImPlotCol_LegendBg
ImPlotCol_LegendBorder
ImPlotCol_LegendText
ImPlotCol_PlotBg
ImPlotCol_PlotBorder
ImPlotCol_Selection
ImPlotCol_TitleText
ImPlotColormapScaleFlags_Invert
ImPlotColormapScaleFlags_NoLabel
ImPlotColormapScaleFlags_None
ImPlotColormapScaleFlags_Opposite
ImPlotColormap_BrBG
ImPlotColormap_Cool
ImPlotColormap_Dark
ImPlotColormap_Deep
ImPlotColormap_Greys
ImPlotColormap_Hot
ImPlotColormap_Jet
ImPlotColormap_Paired
ImPlotColormap_Pastel
ImPlotColormap_PiYG
ImPlotColormap_Pink
ImPlotColormap_Plasma
ImPlotColormap_RdBu
ImPlotColormap_Spectral
ImPlotColormap_Twilight
ImPlotColormap_Viridis
ImPlotCond_Always
ImPlotCond_None
ImPlotCond_Once
ImPlotDateFmt_DayMo
ImPlotDateFmt_DayMoYr
ImPlotDateFmt_Mo
ImPlotDateFmt_MoYr
ImPlotDateFmt_None
ImPlotDateFmt_Yr
ImPlotDigitalFlags_None
ImPlotDragToolFlags_Delayed
ImPlotDragToolFlags_NoCursors
ImPlotDragToolFlags_NoFit
ImPlotDragToolFlags_NoInputs
ImPlotDragToolFlags_None
ImPlotDummyFlags_None
ImPlotErrorBarsFlags_Horizontal
ImPlotErrorBarsFlags_None
ImPlotFlags_CanvasOnly
ImPlotFlags_Crosshairs
ImPlotFlags_Equal
ImPlotFlags_NoBoxSelect
ImPlotFlags_NoFrame
ImPlotFlags_NoInputs
ImPlotFlags_NoLegend
ImPlotFlags_NoMenus
ImPlotFlags_NoMouseText
ImPlotFlags_NoTitle
ImPlotFlags_None
ImPlotHeatmapFlags_ColMajor
ImPlotHeatmapFlags_None
ImPlotHistogramFlags_ColMajor
ImPlotHistogramFlags_Cumulative
ImPlotHistogramFlags_Density
ImPlotHistogramFlags_Horizontal
ImPlotHistogramFlags_NoOutliers
ImPlotHistogramFlags_None
ImPlotImageFlags_None
ImPlotInfLinesFlags_Horizontal
ImPlotInfLinesFlags_None
ImPlotItemFlags_NoFit
ImPlotItemFlags_NoLegend
ImPlotItemFlags_None
ImPlotLegendFlags_Horizontal
ImPlotLegendFlags_NoButtons
ImPlotLegendFlags_NoHighlightAxis
ImPlotLegendFlags_NoHighlightItem
ImPlotLegendFlags_NoMenus
ImPlotLegendFlags_None
ImPlotLegendFlags_Outside
ImPlotLegendFlags_Reverse
ImPlotLegendFlags_Sort
ImPlotLineFlags_Loop
ImPlotLineFlags_NoClip
ImPlotLineFlags_None
ImPlotLineFlags_Segments
ImPlotLineFlags_Shaded
ImPlotLineFlags_SkipNaN
ImPlotLocation_Center
ImPlotLocation_East
ImPlotLocation_North
ImPlotLocation_NorthEast
ImPlotLocation_NorthWest
ImPlotLocation_South
ImPlotLocation_SouthEast
ImPlotLocation_SouthWest
ImPlotLocation_West
ImPlotMarker_Asterisk
ImPlotMarker_Auto
ImPlotMarker_COUNT
ImPlotMarker_Circle
ImPlotMarker_Cross
ImPlotMarker_Diamond
ImPlotMarker_Down
ImPlotMarker_Invalid
ImPlotMarker_Left
ImPlotMarker_None
ImPlotMarker_Plus
ImPlotMarker_Right
ImPlotMarker_Square
ImPlotMarker_Up
ImPlotMouseTextFlags_NoAuxAxes
ImPlotMouseTextFlags_NoFormat
ImPlotMouseTextFlags_None
ImPlotMouseTextFlags_ShowAlways
ImPlotPieChartFlags_Exploding
ImPlotPieChartFlags_IgnoreHidden
ImPlotPieChartFlags_NoSliceBorder
ImPlotPieChartFlags_None
ImPlotPieChartFlags_Normalize
ImPlotPolygonFlags_Concave
ImPlotPolygonFlags_None
ImPlotProp_FillAlpha
ImPlotProp_FillColor
ImPlotProp_FillColors
ImPlotProp_Flags
ImPlotProp_LineColor
ImPlotProp_LineColors
ImPlotProp_LineWeight
ImPlotProp_Marker
ImPlotProp_MarkerFillColor
ImPlotProp_MarkerFillColors
ImPlotProp_MarkerLineColor
ImPlotProp_MarkerLineColors
ImPlotProp_MarkerSize
ImPlotProp_MarkerSizes
ImPlotProp_Offset
ImPlotProp_Size
ImPlotProp_Stride
ImPlotScale_Linear
ImPlotScale_Log10
ImPlotScale_SymLog
ImPlotScale_Time
ImPlotScatterFlags_NoClip
ImPlotScatterFlags_None
ImPlotShadedFlags_None
ImPlotStairsFlags_None
ImPlotStairsFlags_PreStep
ImPlotStairsFlags_Shaded
ImPlotStemsFlags_Horizontal
ImPlotStemsFlags_None
ImPlotStyleVar_AnnotationPadding
ImPlotStyleVar_COUNT
ImPlotStyleVar_DigitalPadding
ImPlotStyleVar_DigitalSpacing
ImPlotStyleVar_FitPadding
ImPlotStyleVar_LabelPadding
ImPlotStyleVar_LegendInnerPadding
ImPlotStyleVar_LegendPadding
ImPlotStyleVar_LegendSpacing
ImPlotStyleVar_MajorGridSize
ImPlotStyleVar_MajorTickLen
ImPlotStyleVar_MajorTickSize
ImPlotStyleVar_MinorAlpha
ImPlotStyleVar_MinorGridSize
ImPlotStyleVar_MinorTickLen
ImPlotStyleVar_MinorTickSize
ImPlotStyleVar_MousePosPadding
ImPlotStyleVar_PlotBorderSize
ImPlotStyleVar_PlotDefaultSize
ImPlotStyleVar_PlotMinSize
ImPlotStyleVar_PlotPadding
ImPlotSubplotFlags_ColMajor
ImPlotSubplotFlags_LinkAllX
ImPlotSubplotFlags_LinkAllY
ImPlotSubplotFlags_LinkCols
ImPlotSubplotFlags_LinkRows
ImPlotSubplotFlags_NoAlign
ImPlotSubplotFlags_NoLegend
ImPlotSubplotFlags_NoMenus
ImPlotSubplotFlags_NoResize
ImPlotSubplotFlags_NoTitle
ImPlotSubplotFlags_None
ImPlotSubplotFlags_ShareItems
ImPlotTextFlags_None
ImPlotTextFlags_Vertical
ImPlotTimeFmt_Hr
ImPlotTimeFmt_HrMin
ImPlotTimeFmt_HrMinS
ImPlotTimeFmt_HrMinSMs
ImPlotTimeFmt_MinSMs
ImPlotTimeFmt_None
ImPlotTimeFmt_S
ImPlotTimeFmt_SMs
ImPlotTimeFmt_SUs
ImPlotTimeFmt_Us
ImPlotTimeUnit_COUNT
ImPlotTimeUnit_Day
ImPlotTimeUnit_Hr
ImPlotTimeUnit_Min
ImPlotTimeUnit_Mo
ImPlotTimeUnit_Ms
ImPlotTimeUnit_S
ImPlotTimeUnit_Us
ImPlotTimeUnit_Yr
ImTextureFormat_Alpha8
ImTextureFormat_RGBA32
ImTextureStatus_Destroyed
ImTextureStatus_OK
ImTextureStatus_WantCreate
ImTextureStatus_WantDestroy
ImTextureStatus_WantUpdates

Functions

ImPlotAlignmentData_Begin⚠
ImPlotAlignmentData_End⚠
ImPlotAlignmentData_ImPlotAlignmentData⚠
ImPlotAlignmentData_Reset⚠
ImPlotAlignmentData_Update⚠
ImPlotAlignmentData_destroy⚠
ImPlotAnnotationCollection_Append⚠
ImPlotAnnotationCollection_AppendV⚠
ImPlotAnnotationCollection_GetText⚠
ImPlotAnnotationCollection_ImPlotAnnotationCollection⚠
ImPlotAnnotationCollection_Reset⚠
ImPlotAnnotationCollection_destroy⚠
ImPlotAnnotation_ImPlotAnnotation⚠
ImPlotAnnotation_destroy⚠
ImPlotAxis_ApplyFit⚠
ImPlotAxis_CanInitFit⚠
ImPlotAxis_Constrain⚠
ImPlotAxis_ExtendFit⚠
ImPlotAxis_ExtendFitWith⚠
ImPlotAxis_GetAspect⚠
ImPlotAxis_HasGridLines⚠
ImPlotAxis_HasLabel⚠
ImPlotAxis_HasMenus⚠
ImPlotAxis_HasTickLabels⚠
ImPlotAxis_HasTickMarks⚠
ImPlotAxis_ImPlotAxis⚠
ImPlotAxis_IsAutoFitting⚠
ImPlotAxis_IsForeground⚠
ImPlotAxis_IsInputLocked⚠
ImPlotAxis_IsInputLockedMax⚠
ImPlotAxis_IsInputLockedMin⚠
ImPlotAxis_IsInverted⚠
ImPlotAxis_IsLocked⚠
ImPlotAxis_IsLockedMax⚠
ImPlotAxis_IsLockedMin⚠
ImPlotAxis_IsOpposite⚠
ImPlotAxis_IsPanLocked⚠
ImPlotAxis_IsRangeLocked⚠
ImPlotAxis_PixelSize⚠
ImPlotAxis_PixelsToPlot⚠
ImPlotAxis_PlotToPixels⚠
ImPlotAxis_PullLinks⚠
ImPlotAxis_PushLinks⚠
ImPlotAxis_Reset⚠
ImPlotAxis_SetAspect⚠
ImPlotAxis_SetMax⚠
ImPlotAxis_SetMin⚠
ImPlotAxis_SetRange_PlotRange⚠
ImPlotAxis_SetRange_double⚠
ImPlotAxis_UpdateTransformCache⚠
ImPlotAxis_WillRender⚠
ImPlotAxis_destroy⚠
ImPlotColormapData_Append⚠
ImPlotColormapData_GetIndex⚠
ImPlotColormapData_GetKeyColor⚠
ImPlotColormapData_GetKeyCount⚠
ImPlotColormapData_GetKeys⚠
ImPlotColormapData_GetName⚠
ImPlotColormapData_GetTable⚠
ImPlotColormapData_GetTableColor⚠
ImPlotColormapData_GetTableSize⚠
ImPlotColormapData_ImPlotColormapData⚠
ImPlotColormapData_IsQual⚠
ImPlotColormapData_LerpTable⚠
ImPlotColormapData_RebuildTables⚠
ImPlotColormapData_SetKeyColor⚠
ImPlotColormapData__AppendTable⚠
ImPlotColormapData_destroy⚠
ImPlotDateTimeSpec_ImPlotDateTimeSpec_Nil⚠
ImPlotDateTimeSpec_ImPlotDateTimeSpec_PlotDateFmt⚠
ImPlotDateTimeSpec_destroy⚠
ImPlotInputMap_ImPlotInputMap⚠
ImPlotInputMap_destroy⚠
ImPlotItemGroup_GetItemByIndex⚠
ImPlotItemGroup_GetItemCount⚠
ImPlotItemGroup_GetItemID⚠
ImPlotItemGroup_GetItemIndex⚠
ImPlotItemGroup_GetItem_ID⚠
ImPlotItemGroup_GetItem_Str⚠
ImPlotItemGroup_GetLegendCount⚠
ImPlotItemGroup_GetLegendItem⚠
ImPlotItemGroup_GetLegendLabel⚠
ImPlotItemGroup_GetOrAddItem⚠
ImPlotItemGroup_ImPlotItemGroup⚠
ImPlotItemGroup_Reset⚠
ImPlotItemGroup_destroy⚠
ImPlotItem_ImPlotItem⚠
ImPlotItem_destroy⚠
ImPlotLegend_ImPlotLegend⚠
ImPlotLegend_Reset⚠
ImPlotLegend_destroy⚠
ImPlotNextItemData_ImPlotNextItemData⚠
ImPlotNextItemData_Reset⚠
ImPlotNextItemData_destroy⚠
ImPlotNextPlotData_ImPlotNextPlotData⚠
ImPlotNextPlotData_Reset⚠
ImPlotNextPlotData_destroy⚠
ImPlotPlot_ClearTextBuffer⚠
ImPlotPlot_EnabledAxesX⚠
ImPlotPlot_EnabledAxesY⚠
ImPlotPlot_GetAxisLabel⚠
ImPlotPlot_GetTitle⚠
ImPlotPlot_HasTitle⚠
ImPlotPlot_ImPlotPlot⚠
ImPlotPlot_IsInputLocked⚠
ImPlotPlot_SetAxisLabel⚠
ImPlotPlot_SetTitle⚠
ImPlotPlot_XAxis_Nil⚠
ImPlotPlot_XAxis__const⚠
ImPlotPlot_YAxis_Nil⚠
ImPlotPlot_YAxis__const⚠
ImPlotPlot_destroy⚠
ImPlotPointError_ImPlotPointError_Nil⚠
ImPlotPointError_ImPlotPointError_double⚠
ImPlotPointError_destroy⚠
ImPlotPoint_ImPlotPoint_Nil⚠
ImPlotPoint_ImPlotPoint_Vec2⚠
ImPlotPoint_ImPlotPoint_double⚠
ImPlotPoint_destroy⚠
ImPlotRange_Clamp⚠
ImPlotRange_Contains⚠
ImPlotRange_ImPlotRange_Nil⚠
ImPlotRange_ImPlotRange_double⚠
ImPlotRange_Size⚠
ImPlotRange_destroy⚠
ImPlotRect_Clamp_PlotPoint⚠
ImPlotRect_Clamp_double⚠
ImPlotRect_Contains_PlotPoint⚠
ImPlotRect_Contains_double⚠
ImPlotRect_ImPlotRect_Nil⚠
ImPlotRect_ImPlotRect_double⚠
ImPlotRect_Max⚠
ImPlotRect_Min⚠
ImPlotRect_Size⚠
ImPlotRect_destroy⚠
ImPlotSpec_ImPlotSpec⚠
ImPlotSpec_SetProp_Float⚠
ImPlotSpec_SetProp_FloatPtr⚠
ImPlotSpec_SetProp_S8⚠
ImPlotSpec_SetProp_S16⚠
ImPlotSpec_SetProp_S32⚠
ImPlotSpec_SetProp_S64⚠
ImPlotSpec_SetProp_U8⚠
ImPlotSpec_SetProp_U16⚠
ImPlotSpec_SetProp_U32⚠
ImPlotSpec_SetProp_U64⚠
ImPlotSpec_SetProp_U32Ptr⚠
ImPlotSpec_SetProp_Vec4⚠
ImPlotSpec_SetProp_double⚠
ImPlotSpec_destroy⚠
ImPlotStyle_ImPlotStyle⚠
ImPlotStyle_destroy⚠
ImPlotSubplot_ImPlotSubplot⚠
ImPlotSubplot_destroy⚠
ImPlotTagCollection_Append⚠
ImPlotTagCollection_AppendV⚠
ImPlotTagCollection_GetText⚠
ImPlotTagCollection_ImPlotTagCollection⚠
ImPlotTagCollection_Reset⚠
ImPlotTagCollection_destroy⚠
ImPlotTag_ImPlotTag⚠
ImPlotTag_destroy⚠
ImPlotTick_ImPlotTick_Nil⚠
ImPlotTick_ImPlotTick_double⚠
ImPlotTick_destroy⚠
ImPlotTicker_AddTick_PlotTick⚠
ImPlotTicker_AddTick_doublePlotFormatter⚠
ImPlotTicker_AddTick_doubleStr⚠
ImPlotTicker_GetText_Int⚠
ImPlotTicker_GetText_PlotTick⚠
ImPlotTicker_ImPlotTicker⚠
ImPlotTicker_OverrideSizeLate⚠
ImPlotTicker_Reset⚠
ImPlotTicker_TickCount⚠
ImPlotTicker_destroy⚠
ImPlotTime_FromDouble⚠
ImPlotTime_ImPlotTime_Nil⚠
ImPlotTime_ImPlotTime_time_t⚠
ImPlotTime_RollOver⚠
ImPlotTime_ToDouble⚠
ImPlotTime_destroy⚠
ImPlot_AddColormap_U32Ptr⚠
ImPlot_AddColormap_Vec4Ptr⚠
ImPlot_AddTextCentered⚠
ImPlot_AddTextVertical⚠
ImPlot_AddTime⚠
ImPlot_AllAxesInputLocked⚠
ImPlot_AnnotationV⚠
ImPlot_Annotation_Bool⚠
ImPlot_Annotation_Str⚠
ImPlot_Annotation_Str0⚠
ImPlot_AnyAxesHeld⚠
ImPlot_AnyAxesHovered⚠
ImPlot_AnyAxesInputLocked⚠
ImPlot_BeginAlignedPlots⚠
ImPlot_BeginDragDropSourceAxis⚠
ImPlot_BeginDragDropSourceItem⚠
ImPlot_BeginDragDropSourcePlot⚠
ImPlot_BeginDragDropTargetAxis⚠
ImPlot_BeginDragDropTargetLegend⚠
ImPlot_BeginDragDropTargetPlot⚠
ImPlot_BeginItem⚠
ImPlot_BeginLegendPopup⚠
ImPlot_BeginPlot⚠
ImPlot_BeginSubplots⚠
ImPlot_BustColorCache⚠
ImPlot_BustItemCache⚠
ImPlot_BustPlotCache⚠
ImPlot_CalcHoverColor⚠
ImPlot_CalcLegendSize⚠
ImPlot_CalcTextColor_U32⚠
ImPlot_CalcTextColor_Vec4⚠
ImPlot_CalcTextSizeVertical⚠
ImPlot_CancelPlotSelection⚠
ImPlot_CeilTime⚠
ImPlot_ClampLabelPos⚠
ImPlot_ClampLegendRect⚠
ImPlot_ColormapButton⚠
ImPlot_ColormapIcon⚠
ImPlot_ColormapScale⚠
ImPlot_ColormapSlider⚠
ImPlot_CombineDateTime⚠
ImPlot_CreateContext⚠
ImPlot_DestroyContext⚠
ImPlot_DragLineX⚠
ImPlot_DragLineY⚠
ImPlot_DragPoint⚠
ImPlot_DragRect⚠
ImPlot_EndAlignedPlots⚠
ImPlot_EndDragDropSource⚠
ImPlot_EndDragDropTarget⚠
ImPlot_EndItem⚠
ImPlot_EndLegendPopup⚠
ImPlot_EndPlot⚠
ImPlot_EndSubplots⚠
ImPlot_FillRange_Vector_Float_Ptr⚠
ImPlot_FillRange_Vector_S8_Ptr⚠
ImPlot_FillRange_Vector_S16_Ptr⚠
ImPlot_FillRange_Vector_S32_Ptr⚠
ImPlot_FillRange_Vector_S64_Ptr⚠
ImPlot_FillRange_Vector_U8_Ptr⚠
ImPlot_FillRange_Vector_U16_Ptr⚠
ImPlot_FillRange_Vector_U32_Ptr⚠
ImPlot_FillRange_Vector_U64_Ptr⚠
ImPlot_FillRange_Vector_double_Ptr⚠
ImPlot_FitPoint⚠
ImPlot_FitPointX⚠
ImPlot_FitPointY⚠
ImPlot_FitThisFrame⚠
ImPlot_FloorTime⚠
ImPlot_FormatDate⚠
ImPlot_FormatDateTime⚠
ImPlot_FormatTime⚠
ImPlot_Formatter_Default⚠
ImPlot_Formatter_Logit⚠
ImPlot_Formatter_Time⚠
ImPlot_GetAutoColor⚠
ImPlot_GetColormapColor⚠
ImPlot_GetColormapColorU32⚠
ImPlot_GetColormapCount⚠
ImPlot_GetColormapIndex⚠
ImPlot_GetColormapName⚠
ImPlot_GetColormapSize⚠
ImPlot_GetCurrentContext⚠
ImPlot_GetCurrentItem⚠
ImPlot_GetCurrentPlot⚠
ImPlot_GetDaysInMonth⚠
ImPlot_GetGmtTime⚠
ImPlot_GetInputMap⚠
ImPlot_GetItem⚠
ImPlot_GetItemData⚠
ImPlot_GetLastItemColor⚠
ImPlot_GetLocTime⚠
ImPlot_GetLocationPos⚠
ImPlot_GetMarkerName⚠
ImPlot_GetMonth⚠
ImPlot_GetPlot⚠
ImPlot_GetPlotDrawList⚠
ImPlot_GetPlotLimits⚠
ImPlot_GetPlotMousePos⚠
ImPlot_GetPlotPos⚠
ImPlot_GetPlotSelection⚠
ImPlot_GetPlotSize⚠
ImPlot_GetStyle⚠
ImPlot_GetStyleColorName⚠
ImPlot_GetStyleColorU32⚠
ImPlot_GetStyleColorVec4⚠
ImPlot_GetTime⚠
ImPlot_GetYear⚠
ImPlot_HideNextItem⚠
ImPlot_ImAlmostEqual⚠
ImPlot_ImAlphaU32⚠
ImPlot_ImAsinh_Float⚠
ImPlot_ImAsinh_double⚠
ImPlot_ImConstrainInf⚠
ImPlot_ImConstrainLog⚠
ImPlot_ImConstrainNan⚠
ImPlot_ImConstrainTime⚠
ImPlot_ImLerpU32⚠
ImPlot_ImLog10_Float⚠
ImPlot_ImLog10_double⚠
ImPlot_ImMaxArray_FloatPtr⚠
ImPlot_ImMaxArray_S8Ptr⚠
ImPlot_ImMaxArray_S16Ptr⚠
ImPlot_ImMaxArray_S32Ptr⚠
ImPlot_ImMaxArray_S64Ptr⚠
ImPlot_ImMaxArray_U8Ptr⚠
ImPlot_ImMaxArray_U16Ptr⚠
ImPlot_ImMaxArray_U32Ptr⚠
ImPlot_ImMaxArray_U64Ptr⚠
ImPlot_ImMaxArray_doublePtr⚠
ImPlot_ImMean_FloatPtr⚠
ImPlot_ImMean_S8Ptr⚠
ImPlot_ImMean_S16Ptr⚠
ImPlot_ImMean_S32Ptr⚠
ImPlot_ImMean_S64Ptr⚠
ImPlot_ImMean_U8Ptr⚠
ImPlot_ImMean_U16Ptr⚠
ImPlot_ImMean_U32Ptr⚠
ImPlot_ImMean_U64Ptr⚠
ImPlot_ImMean_doublePtr⚠
ImPlot_ImMinArray_FloatPtr⚠
ImPlot_ImMinArray_S8Ptr⚠
ImPlot_ImMinArray_S16Ptr⚠
ImPlot_ImMinArray_S32Ptr⚠
ImPlot_ImMinArray_S64Ptr⚠
ImPlot_ImMinArray_U8Ptr⚠
ImPlot_ImMinArray_U16Ptr⚠
ImPlot_ImMinArray_U32Ptr⚠
ImPlot_ImMinArray_U64Ptr⚠
ImPlot_ImMinArray_doublePtr⚠
ImPlot_ImMinMaxArray_FloatPtr⚠
ImPlot_ImMinMaxArray_S8Ptr⚠
ImPlot_ImMinMaxArray_S16Ptr⚠
ImPlot_ImMinMaxArray_S32Ptr⚠
ImPlot_ImMinMaxArray_S64Ptr⚠
ImPlot_ImMinMaxArray_U8Ptr⚠
ImPlot_ImMinMaxArray_U16Ptr⚠
ImPlot_ImMinMaxArray_U32Ptr⚠
ImPlot_ImMinMaxArray_U64Ptr⚠
ImPlot_ImMinMaxArray_doublePtr⚠
ImPlot_ImMixU32⚠
ImPlot_ImNan⚠
ImPlot_ImNanOrInf⚠
ImPlot_ImOverlaps_Float⚠
ImPlot_ImOverlaps_S8⚠
ImPlot_ImOverlaps_S16⚠
ImPlot_ImOverlaps_S32⚠
ImPlot_ImOverlaps_S64⚠
ImPlot_ImOverlaps_U8⚠
ImPlot_ImOverlaps_U16⚠
ImPlot_ImOverlaps_U32⚠
ImPlot_ImOverlaps_U64⚠
ImPlot_ImOverlaps_double⚠
ImPlot_ImPosMod⚠
ImPlot_ImRemap01_Float⚠
ImPlot_ImRemap01_S8⚠
ImPlot_ImRemap01_S16⚠
ImPlot_ImRemap01_S32⚠
ImPlot_ImRemap01_S64⚠
ImPlot_ImRemap01_U8⚠
ImPlot_ImRemap01_U16⚠
ImPlot_ImRemap01_U32⚠
ImPlot_ImRemap01_U64⚠
ImPlot_ImRemap01_double⚠
ImPlot_ImRemap_Float⚠
ImPlot_ImRemap_S8⚠
ImPlot_ImRemap_S16⚠
ImPlot_ImRemap_S32⚠
ImPlot_ImRemap_S64⚠
ImPlot_ImRemap_U8⚠
ImPlot_ImRemap_U16⚠
ImPlot_ImRemap_U32⚠
ImPlot_ImRemap_U64⚠
ImPlot_ImRemap_double⚠
ImPlot_ImSinh_Float⚠
ImPlot_ImSinh_double⚠
ImPlot_ImStdDev_FloatPtr⚠
ImPlot_ImStdDev_S8Ptr⚠
ImPlot_ImStdDev_S16Ptr⚠
ImPlot_ImStdDev_S32Ptr⚠
ImPlot_ImStdDev_S64Ptr⚠
ImPlot_ImStdDev_U8Ptr⚠
ImPlot_ImStdDev_U16Ptr⚠
ImPlot_ImStdDev_U32Ptr⚠
ImPlot_ImStdDev_U64Ptr⚠
ImPlot_ImStdDev_doublePtr⚠
ImPlot_ImSum_FloatPtr⚠
ImPlot_ImSum_S8Ptr⚠
ImPlot_ImSum_S16Ptr⚠
ImPlot_ImSum_S32Ptr⚠
ImPlot_ImSum_S64Ptr⚠
ImPlot_ImSum_U8Ptr⚠
ImPlot_ImSum_U16Ptr⚠
ImPlot_ImSum_U32Ptr⚠
ImPlot_ImSum_U64Ptr⚠
ImPlot_ImSum_doublePtr⚠
ImPlot_Initialize⚠
ImPlot_Intersection⚠
ImPlot_IsAxisHovered⚠
ImPlot_IsColorAuto_PlotCol⚠
ImPlot_IsColorAuto_Vec4⚠
ImPlot_IsLeapYear⚠
ImPlot_IsLegendEntryHovered⚠
ImPlot_IsPlotHovered⚠
ImPlot_IsPlotSelected⚠
ImPlot_IsSubplotsHovered⚠
ImPlot_ItemIcon_U32⚠
ImPlot_ItemIcon_Vec4⚠
ImPlot_LabelAxisValue⚠
ImPlot_Locator_Default⚠
ImPlot_Locator_Log10⚠
ImPlot_Locator_SymLog⚠
ImPlot_Locator_Time⚠
ImPlot_MakeTime⚠
ImPlot_MapInputDefault⚠
ImPlot_MapInputReverse⚠
ImPlot_MkGmtTime⚠
ImPlot_MkLocTime⚠
ImPlot_MkTime⚠
ImPlot_NextColormapColor⚠
ImPlot_NextColormapColorU32⚠
ImPlot_NextMarker⚠
ImPlot_NiceNum⚠
ImPlot_Now⚠
ImPlot_OrderOfMagnitude⚠
ImPlot_OrderToPrecision⚠
ImPlot_PixelsToPlot_Float⚠
ImPlot_PixelsToPlot_Vec2⚠
ImPlot_PlotBarGroups_FloatPtr⚠
ImPlot_PlotBarGroups_S8Ptr⚠
ImPlot_PlotBarGroups_S16Ptr⚠
ImPlot_PlotBarGroups_S32Ptr⚠
ImPlot_PlotBarGroups_S64Ptr⚠
ImPlot_PlotBarGroups_U8Ptr⚠
ImPlot_PlotBarGroups_U16Ptr⚠
ImPlot_PlotBarGroups_U32Ptr⚠
ImPlot_PlotBarGroups_U64Ptr⚠
ImPlot_PlotBarGroups_doublePtr⚠
ImPlot_PlotBarsG⚠
ImPlot_PlotBarsG_LJ⚠
ImPlot_PlotBars_FloatPtrFloatPtr⚠
ImPlot_PlotBars_FloatPtrInt⚠
ImPlot_PlotBars_S8PtrInt⚠
ImPlot_PlotBars_S8PtrS8Ptr⚠
ImPlot_PlotBars_S16PtrInt⚠
ImPlot_PlotBars_S16PtrS16Ptr⚠
ImPlot_PlotBars_S32PtrInt⚠
ImPlot_PlotBars_S32PtrS32Ptr⚠
ImPlot_PlotBars_S64PtrInt⚠
ImPlot_PlotBars_S64PtrS64Ptr⚠
ImPlot_PlotBars_U8PtrInt⚠
ImPlot_PlotBars_U8PtrU8Ptr⚠
ImPlot_PlotBars_U16PtrInt⚠
ImPlot_PlotBars_U16PtrU16Ptr⚠
ImPlot_PlotBars_U32PtrInt⚠
ImPlot_PlotBars_U32PtrU32Ptr⚠
ImPlot_PlotBars_U64PtrInt⚠
ImPlot_PlotBars_U64PtrU64Ptr⚠
ImPlot_PlotBars_doublePtrInt⚠
ImPlot_PlotBars_doublePtrdoublePtr⚠
ImPlot_PlotBubbles_FloatPtrFloatPtrFloatPtr⚠
ImPlot_PlotBubbles_FloatPtrFloatPtrInt⚠
ImPlot_PlotBubbles_S8PtrS8PtrInt⚠
ImPlot_PlotBubbles_S8PtrS8PtrS8Ptr⚠
ImPlot_PlotBubbles_S16PtrS16PtrInt⚠
ImPlot_PlotBubbles_S16PtrS16PtrS16Ptr⚠
ImPlot_PlotBubbles_S32PtrS32PtrInt⚠
ImPlot_PlotBubbles_S32PtrS32PtrS32Ptr⚠
ImPlot_PlotBubbles_S64PtrS64PtrInt⚠
ImPlot_PlotBubbles_S64PtrS64PtrS64Ptr⚠
ImPlot_PlotBubbles_U8PtrU8PtrInt⚠
ImPlot_PlotBubbles_U8PtrU8PtrU8Ptr⚠
ImPlot_PlotBubbles_U16PtrU16PtrInt⚠
ImPlot_PlotBubbles_U16PtrU16PtrU16Ptr⚠
ImPlot_PlotBubbles_U32PtrU32PtrInt⚠
ImPlot_PlotBubbles_U32PtrU32PtrU32Ptr⚠
ImPlot_PlotBubbles_U64PtrU64PtrInt⚠
ImPlot_PlotBubbles_U64PtrU64PtrU64Ptr⚠
ImPlot_PlotBubbles_doublePtrdoublePtrInt⚠
ImPlot_PlotBubbles_doublePtrdoublePtrdoublePtr⚠
ImPlot_PlotDigitalG⚠
ImPlot_PlotDigitalG_LJ⚠
ImPlot_PlotDigital_FloatPtr⚠
ImPlot_PlotDigital_S8Ptr⚠
ImPlot_PlotDigital_S16Ptr⚠
ImPlot_PlotDigital_S32Ptr⚠
ImPlot_PlotDigital_S64Ptr⚠
ImPlot_PlotDigital_U8Ptr⚠
ImPlot_PlotDigital_U16Ptr⚠
ImPlot_PlotDigital_U32Ptr⚠
ImPlot_PlotDigital_U64Ptr⚠
ImPlot_PlotDigital_doublePtr⚠
ImPlot_PlotDummy⚠
ImPlot_PlotErrorBars_FloatPtrFloatPtrFloatPtrFloatPtr⚠
ImPlot_PlotErrorBars_FloatPtrFloatPtrFloatPtrInt⚠
ImPlot_PlotErrorBars_S8PtrS8PtrS8PtrInt⚠
ImPlot_PlotErrorBars_S8PtrS8PtrS8PtrS8Ptr⚠
ImPlot_PlotErrorBars_S16PtrS16PtrS16PtrInt⚠
ImPlot_PlotErrorBars_S16PtrS16PtrS16PtrS16Ptr⚠
ImPlot_PlotErrorBars_S32PtrS32PtrS32PtrInt⚠
ImPlot_PlotErrorBars_S32PtrS32PtrS32PtrS32Ptr⚠
ImPlot_PlotErrorBars_S64PtrS64PtrS64PtrInt⚠
ImPlot_PlotErrorBars_S64PtrS64PtrS64PtrS64Ptr⚠
ImPlot_PlotErrorBars_U8PtrU8PtrU8PtrInt⚠
ImPlot_PlotErrorBars_U8PtrU8PtrU8PtrU8Ptr⚠
ImPlot_PlotErrorBars_U16PtrU16PtrU16PtrInt⚠
ImPlot_PlotErrorBars_U16PtrU16PtrU16PtrU16Ptr⚠
ImPlot_PlotErrorBars_U32PtrU32PtrU32PtrInt⚠
ImPlot_PlotErrorBars_U32PtrU32PtrU32PtrU32Ptr⚠
ImPlot_PlotErrorBars_U64PtrU64PtrU64PtrInt⚠
ImPlot_PlotErrorBars_U64PtrU64PtrU64PtrU64Ptr⚠
ImPlot_PlotErrorBars_doublePtrdoublePtrdoublePtrInt⚠
ImPlot_PlotErrorBars_doublePtrdoublePtrdoublePtrdoublePtr⚠
ImPlot_PlotHeatmap_FloatPtr⚠
ImPlot_PlotHeatmap_S8Ptr⚠
ImPlot_PlotHeatmap_S16Ptr⚠
ImPlot_PlotHeatmap_S32Ptr⚠
ImPlot_PlotHeatmap_S64Ptr⚠
ImPlot_PlotHeatmap_U8Ptr⚠
ImPlot_PlotHeatmap_U16Ptr⚠
ImPlot_PlotHeatmap_U32Ptr⚠
ImPlot_PlotHeatmap_U64Ptr⚠
ImPlot_PlotHeatmap_doublePtr⚠
ImPlot_PlotHistogram2D_FloatPtr⚠
ImPlot_PlotHistogram2D_S8Ptr⚠
ImPlot_PlotHistogram2D_S16Ptr⚠
ImPlot_PlotHistogram2D_S32Ptr⚠
ImPlot_PlotHistogram2D_S64Ptr⚠
ImPlot_PlotHistogram2D_U8Ptr⚠
ImPlot_PlotHistogram2D_U16Ptr⚠
ImPlot_PlotHistogram2D_U32Ptr⚠
ImPlot_PlotHistogram2D_U64Ptr⚠
ImPlot_PlotHistogram2D_doublePtr⚠
ImPlot_PlotHistogram_FloatPtr⚠
ImPlot_PlotHistogram_S8Ptr⚠
ImPlot_PlotHistogram_S16Ptr⚠
ImPlot_PlotHistogram_S32Ptr⚠
ImPlot_PlotHistogram_S64Ptr⚠
ImPlot_PlotHistogram_U8Ptr⚠
ImPlot_PlotHistogram_U16Ptr⚠
ImPlot_PlotHistogram_U32Ptr⚠
ImPlot_PlotHistogram_U64Ptr⚠
ImPlot_PlotHistogram_doublePtr⚠
ImPlot_PlotImage⚠
ImPlot_PlotInfLines_FloatPtr⚠
ImPlot_PlotInfLines_S8Ptr⚠
ImPlot_PlotInfLines_S16Ptr⚠
ImPlot_PlotInfLines_S32Ptr⚠
ImPlot_PlotInfLines_S64Ptr⚠
ImPlot_PlotInfLines_U8Ptr⚠
ImPlot_PlotInfLines_U16Ptr⚠
ImPlot_PlotInfLines_U32Ptr⚠
ImPlot_PlotInfLines_U64Ptr⚠
ImPlot_PlotInfLines_doublePtr⚠
ImPlot_PlotLineG⚠
ImPlot_PlotLineG_LJ⚠
ImPlot_PlotLine_FloatPtrFloatPtr⚠
ImPlot_PlotLine_FloatPtrInt⚠
ImPlot_PlotLine_S8PtrInt⚠
ImPlot_PlotLine_S8PtrS8Ptr⚠
ImPlot_PlotLine_S16PtrInt⚠
ImPlot_PlotLine_S16PtrS16Ptr⚠
ImPlot_PlotLine_S32PtrInt⚠
ImPlot_PlotLine_S32PtrS32Ptr⚠
ImPlot_PlotLine_S64PtrInt⚠
ImPlot_PlotLine_S64PtrS64Ptr⚠
ImPlot_PlotLine_U8PtrInt⚠
ImPlot_PlotLine_U8PtrU8Ptr⚠
ImPlot_PlotLine_U16PtrInt⚠
ImPlot_PlotLine_U16PtrU16Ptr⚠
ImPlot_PlotLine_U32PtrInt⚠
ImPlot_PlotLine_U32PtrU32Ptr⚠
ImPlot_PlotLine_U64PtrInt⚠
ImPlot_PlotLine_U64PtrU64Ptr⚠
ImPlot_PlotLine_doublePtrInt⚠
ImPlot_PlotLine_doublePtrdoublePtr⚠
ImPlot_PlotPieChart_FloatPtrPlotFormatter⚠
ImPlot_PlotPieChart_FloatPtrStr⚠
ImPlot_PlotPieChart_S8PtrPlotFormatter⚠
ImPlot_PlotPieChart_S8PtrStr⚠
ImPlot_PlotPieChart_S16PtrPlotFormatter⚠
ImPlot_PlotPieChart_S16PtrStr⚠
ImPlot_PlotPieChart_S32PtrPlotFormatter⚠
ImPlot_PlotPieChart_S32PtrStr⚠
ImPlot_PlotPieChart_S64PtrPlotFormatter⚠
ImPlot_PlotPieChart_S64PtrStr⚠
ImPlot_PlotPieChart_U8PtrPlotFormatter⚠
ImPlot_PlotPieChart_U8PtrStr⚠
ImPlot_PlotPieChart_U16PtrPlotFormatter⚠
ImPlot_PlotPieChart_U16PtrStr⚠
ImPlot_PlotPieChart_U32PtrPlotFormatter⚠
ImPlot_PlotPieChart_U32PtrStr⚠
ImPlot_PlotPieChart_U64PtrPlotFormatter⚠
ImPlot_PlotPieChart_U64PtrStr⚠
ImPlot_PlotPieChart_doublePtrPlotFormatter⚠
ImPlot_PlotPieChart_doublePtrStr⚠
ImPlot_PlotPolygon_FloatPtr⚠
ImPlot_PlotPolygon_S8Ptr⚠
ImPlot_PlotPolygon_S16Ptr⚠
ImPlot_PlotPolygon_S32Ptr⚠
ImPlot_PlotPolygon_S64Ptr⚠
ImPlot_PlotPolygon_U8Ptr⚠
ImPlot_PlotPolygon_U16Ptr⚠
ImPlot_PlotPolygon_U32Ptr⚠
ImPlot_PlotPolygon_U64Ptr⚠
ImPlot_PlotPolygon_doublePtr⚠
ImPlot_PlotScatterG⚠
ImPlot_PlotScatterG_LJ⚠
ImPlot_PlotScatter_FloatPtrFloatPtr⚠
ImPlot_PlotScatter_FloatPtrInt⚠
ImPlot_PlotScatter_S8PtrInt⚠
ImPlot_PlotScatter_S8PtrS8Ptr⚠
ImPlot_PlotScatter_S16PtrInt⚠
ImPlot_PlotScatter_S16PtrS16Ptr⚠
ImPlot_PlotScatter_S32PtrInt⚠
ImPlot_PlotScatter_S32PtrS32Ptr⚠
ImPlot_PlotScatter_S64PtrInt⚠
ImPlot_PlotScatter_S64PtrS64Ptr⚠
ImPlot_PlotScatter_U8PtrInt⚠
ImPlot_PlotScatter_U8PtrU8Ptr⚠
ImPlot_PlotScatter_U16PtrInt⚠
ImPlot_PlotScatter_U16PtrU16Ptr⚠
ImPlot_PlotScatter_U32PtrInt⚠
ImPlot_PlotScatter_U32PtrU32Ptr⚠
ImPlot_PlotScatter_U64PtrInt⚠
ImPlot_PlotScatter_U64PtrU64Ptr⚠
ImPlot_PlotScatter_doublePtrInt⚠
ImPlot_PlotScatter_doublePtrdoublePtr⚠
ImPlot_PlotShadedG⚠
ImPlot_PlotShadedG_LJ⚠
ImPlot_PlotShaded_FloatPtrFloatPtrFloatPtr⚠
ImPlot_PlotShaded_FloatPtrFloatPtrInt⚠
ImPlot_PlotShaded_FloatPtrInt⚠
ImPlot_PlotShaded_S8PtrInt⚠
ImPlot_PlotShaded_S8PtrS8PtrInt⚠
ImPlot_PlotShaded_S8PtrS8PtrS8Ptr⚠
ImPlot_PlotShaded_S16PtrInt⚠
ImPlot_PlotShaded_S16PtrS16PtrInt⚠
ImPlot_PlotShaded_S16PtrS16PtrS16Ptr⚠
ImPlot_PlotShaded_S32PtrInt⚠
ImPlot_PlotShaded_S32PtrS32PtrInt⚠
ImPlot_PlotShaded_S32PtrS32PtrS32Ptr⚠
ImPlot_PlotShaded_S64PtrInt⚠
ImPlot_PlotShaded_S64PtrS64PtrInt⚠
ImPlot_PlotShaded_S64PtrS64PtrS64Ptr⚠
ImPlot_PlotShaded_U8PtrInt⚠
ImPlot_PlotShaded_U8PtrU8PtrInt⚠
ImPlot_PlotShaded_U8PtrU8PtrU8Ptr⚠
ImPlot_PlotShaded_U16PtrInt⚠
ImPlot_PlotShaded_U16PtrU16PtrInt⚠
ImPlot_PlotShaded_U16PtrU16PtrU16Ptr⚠
ImPlot_PlotShaded_U32PtrInt⚠
ImPlot_PlotShaded_U32PtrU32PtrInt⚠
ImPlot_PlotShaded_U32PtrU32PtrU32Ptr⚠
ImPlot_PlotShaded_U64PtrInt⚠
ImPlot_PlotShaded_U64PtrU64PtrInt⚠
ImPlot_PlotShaded_U64PtrU64PtrU64Ptr⚠
ImPlot_PlotShaded_doublePtrInt⚠
ImPlot_PlotShaded_doublePtrdoublePtrInt⚠
ImPlot_PlotShaded_doublePtrdoublePtrdoublePtr⚠
ImPlot_PlotStairsG⚠
ImPlot_PlotStairsG_LJ⚠
ImPlot_PlotStairs_FloatPtrFloatPtr⚠
ImPlot_PlotStairs_FloatPtrInt⚠
ImPlot_PlotStairs_S8PtrInt⚠
ImPlot_PlotStairs_S8PtrS8Ptr⚠
ImPlot_PlotStairs_S16PtrInt⚠
ImPlot_PlotStairs_S16PtrS16Ptr⚠
ImPlot_PlotStairs_S32PtrInt⚠
ImPlot_PlotStairs_S32PtrS32Ptr⚠
ImPlot_PlotStairs_S64PtrInt⚠
ImPlot_PlotStairs_S64PtrS64Ptr⚠
ImPlot_PlotStairs_U8PtrInt⚠
ImPlot_PlotStairs_U8PtrU8Ptr⚠
ImPlot_PlotStairs_U16PtrInt⚠
ImPlot_PlotStairs_U16PtrU16Ptr⚠
ImPlot_PlotStairs_U32PtrInt⚠
ImPlot_PlotStairs_U32PtrU32Ptr⚠
ImPlot_PlotStairs_U64PtrInt⚠
ImPlot_PlotStairs_U64PtrU64Ptr⚠
ImPlot_PlotStairs_doublePtrInt⚠
ImPlot_PlotStairs_doublePtrdoublePtr⚠
ImPlot_PlotStems_FloatPtrFloatPtr⚠
ImPlot_PlotStems_FloatPtrInt⚠
ImPlot_PlotStems_S8PtrInt⚠
ImPlot_PlotStems_S8PtrS8Ptr⚠
ImPlot_PlotStems_S16PtrInt⚠
ImPlot_PlotStems_S16PtrS16Ptr⚠
ImPlot_PlotStems_S32PtrInt⚠
ImPlot_PlotStems_S32PtrS32Ptr⚠
ImPlot_PlotStems_S64PtrInt⚠
ImPlot_PlotStems_S64PtrS64Ptr⚠
ImPlot_PlotStems_U8PtrInt⚠
ImPlot_PlotStems_U8PtrU8Ptr⚠
ImPlot_PlotStems_U16PtrInt⚠
ImPlot_PlotStems_U16PtrU16Ptr⚠
ImPlot_PlotStems_U32PtrInt⚠
ImPlot_PlotStems_U32PtrU32Ptr⚠
ImPlot_PlotStems_U64PtrInt⚠
ImPlot_PlotStems_U64PtrU64Ptr⚠
ImPlot_PlotStems_doublePtrInt⚠
ImPlot_PlotStems_doublePtrdoublePtr⚠
ImPlot_PlotText⚠
ImPlot_PlotToPixels_PlotPoint⚠
ImPlot_PlotToPixels_double⚠
ImPlot_PopColormap⚠
ImPlot_PopPlotClipRect⚠
ImPlot_PopStyleColor⚠
ImPlot_PopStyleVar⚠
ImPlot_Precision⚠
ImPlot_PushColormap_PlotColormap⚠
ImPlot_PushColormap_Str⚠
ImPlot_PushPlotClipRect⚠
ImPlot_PushStyleColor_U32⚠
ImPlot_PushStyleColor_Vec4⚠
ImPlot_PushStyleVar_Float⚠
ImPlot_PushStyleVar_Int⚠
ImPlot_PushStyleVar_Vec2⚠
ImPlot_RangesOverlap⚠
ImPlot_RegisterOrGetItem⚠
ImPlot_RenderColorBar⚠
ImPlot_ResetCtxForNextAlignedPlots⚠
ImPlot_ResetCtxForNextPlot⚠
ImPlot_ResetCtxForNextSubplot⚠
ImPlot_RoundTime⚠
ImPlot_RoundTo⚠
ImPlot_SampleColormap⚠
ImPlot_SampleColormapU32⚠
ImPlot_SetAxes⚠
ImPlot_SetAxis⚠
ImPlot_SetCurrentContext⚠
ImPlot_SetImGuiContext⚠
ImPlot_SetNextAxesLimits⚠
ImPlot_SetNextAxesToFit⚠
ImPlot_SetNextAxisLimits⚠
ImPlot_SetNextAxisLinks⚠
ImPlot_SetNextAxisToFit⚠
ImPlot_SetupAxes⚠
ImPlot_SetupAxesLimits⚠
ImPlot_SetupAxis⚠
ImPlot_SetupAxisFormat_PlotFormatter⚠
ImPlot_SetupAxisFormat_Str⚠
ImPlot_SetupAxisLimits⚠
ImPlot_SetupAxisLimitsConstraints⚠
ImPlot_SetupAxisLinks⚠
ImPlot_SetupAxisScale_PlotScale⚠
ImPlot_SetupAxisScale_PlotTransform⚠
ImPlot_SetupAxisTicks_double⚠
ImPlot_SetupAxisTicks_doublePtr⚠
ImPlot_SetupAxisZoomConstraints⚠
ImPlot_SetupFinish⚠
ImPlot_SetupLegend⚠
ImPlot_SetupLock⚠
ImPlot_SetupMouseText⚠
ImPlot_ShowAltLegend⚠
ImPlot_ShowAxisContextMenu⚠
ImPlot_ShowColormapSelector⚠
ImPlot_ShowDatePicker⚠
ImPlot_ShowDemoWindow⚠
ImPlot_ShowInputMapSelector⚠
ImPlot_ShowLegendContextMenu⚠
ImPlot_ShowLegendEntries⚠
ImPlot_ShowMetricsWindow⚠
ImPlot_ShowPlotContextMenu⚠
ImPlot_ShowStyleEditor⚠
ImPlot_ShowStyleSelector⚠
ImPlot_ShowSubplotsContextMenu⚠
ImPlot_ShowTimePicker⚠
ImPlot_ShowUserGuide⚠
ImPlot_StyleColorsAuto⚠
ImPlot_StyleColorsClassic⚠
ImPlot_StyleColorsDark⚠
ImPlot_StyleColorsLight⚠
ImPlot_SubplotNextCell⚠
ImPlot_TagXV⚠
ImPlot_TagX_Bool⚠
ImPlot_TagX_Str⚠
ImPlot_TagX_Str0⚠
ImPlot_TagYV⚠
ImPlot_TagY_Bool⚠
ImPlot_TagY_Str⚠
ImPlot_TagY_Str0⚠
ImPlot_Today⚠
ImPlot_TransformForward_Log10⚠
ImPlot_TransformForward_Logit⚠
ImPlot_TransformForward_SymLog⚠
ImPlot_TransformInverse_Log10⚠
ImPlot_TransformInverse_Logit⚠
ImPlot_TransformInverse_SymLog⚠

Type Aliases

FILE
ImAxis
ImBitArrayForNamedKeys
ImBitArrayPtr
ImDrawCallback
ImDrawIdx
ImDrawListFlags
ImFileHandle
ImFontAtlasFlags
ImFontAtlasRectId
ImFontFlags
ImGuiActivateFlags
ImGuiAxis
ImGuiBackendFlags
ImGuiChildFlags
ImGuiCol
ImGuiColorEditFlags
ImGuiCond
ImGuiConfigFlags
ImGuiContextHookCallback
ImGuiContextHookType
ImGuiDebugLogFlags
ImGuiDemoMarkerCallback
ImGuiDir
ImGuiDockNodeFlags
ImGuiDockNodeState
ImGuiDragDropFlags
ImGuiErrorCallback
ImGuiHoveredFlags
ImGuiID
ImGuiInputEventType
ImGuiInputFlags
ImGuiInputSource
ImGuiInputTextFlags
ImGuiItemFlags
ImGuiItemStatusFlags
ImGuiKey
ImGuiKeyChord
ImGuiKeyRoutingIndex
ImGuiLayoutType
ImGuiListClipperFlags
ImGuiLogFlags
ImGuiMouseButton
ImGuiMouseCursor
ImGuiMouseSource
ImGuiMultiSelectFlags
ImGuiNavLayer
ImGuiNavMoveFlags
ImGuiNextItemDataFlags
ImGuiNextWindowDataFlags
ImGuiOldColumnFlags
ImGuiScrollFlags
ImGuiSelectionRequestType
ImGuiSelectionUserData
ImGuiSizeCallback
ImGuiSortDirection
ImGuiStyleVar
ImGuiTabBarFlags
ImGuiTabItemFlags
ImGuiTableColumnFlags
ImGuiTableColumnIdx
ImGuiTableDrawChannelIdx
ImGuiTableFlags
ImGuiTableRowFlags
ImGuiTreeNodeFlags
ImGuiTypingSelectFlags
ImGuiViewportFlags
ImGuiWindowBgClickFlags
ImGuiWindowFlags
ImGuiWindowRefreshFlags
ImPlotAxis
ImPlotAxisFlags
ImPlotAxisFlags_
ImPlotBarGroupsFlags
ImPlotBarGroupsFlags_
ImPlotBarsFlags
ImPlotBarsFlags_
ImPlotBin
ImPlotBin_
ImPlotBubblesFlags
ImPlotBubblesFlags_
ImPlotCol
ImPlotCol_
ImPlotColormap
ImPlotColormapScaleFlags
ImPlotColormapScaleFlags_
ImPlotColormap_
ImPlotCond
ImPlotCond_
ImPlotDateFmt
ImPlotDateFmt_
ImPlotDateTimeSpec
ImPlotDigitalFlags
ImPlotDigitalFlags_
ImPlotDragToolFlags
ImPlotDragToolFlags_
ImPlotDummyFlags
ImPlotDummyFlags_
ImPlotErrorBarsFlags
ImPlotErrorBarsFlags_
ImPlotFlags
ImPlotFlags_
ImPlotFormatter
ImPlotGetter
ImPlotHeatmapFlags
ImPlotHeatmapFlags_
ImPlotHistogramFlags
ImPlotHistogramFlags_
ImPlotImageFlags
ImPlotImageFlags_
ImPlotInfLinesFlags
ImPlotInfLinesFlags_
ImPlotItemFlags
ImPlotItemFlags_
ImPlotLegendFlags
ImPlotLegendFlags_
ImPlotLineFlags
ImPlotLineFlags_
ImPlotLocation
ImPlotLocation_
ImPlotLocator
ImPlotMarker
ImPlotMarkerInternal
ImPlotMarkerInternal_
ImPlotMarker_
ImPlotMouseTextFlags
ImPlotMouseTextFlags_
ImPlotPieChartFlags
ImPlotPieChartFlags_
ImPlotPoint
ImPlotPoint_getter
ImPlotPolygonFlags
ImPlotPolygonFlags_
ImPlotProp
ImPlotProp_
ImPlotRange
ImPlotRect
ImPlotScale
ImPlotScale_
ImPlotScatterFlags
ImPlotScatterFlags_
ImPlotShadedFlags
ImPlotShadedFlags_
ImPlotSpec
ImPlotStairsFlags
ImPlotStairsFlags_
ImPlotStemsFlags
ImPlotStemsFlags_
ImPlotStyleVar
ImPlotStyleVar_
ImPlotSubplotFlags
ImPlotSubplotFlags_
ImPlotTextFlags
ImPlotTextFlags_
ImPlotTick
ImPlotTime
ImPlotTimeFmt
ImPlotTimeFmt_
ImPlotTimeUnit
ImPlotTimeUnit_
ImPlotTransform
ImPoolIdx
ImRect
ImS8
ImS16
ImS32
ImS64
ImStbTexteditState
ImTextureFormat
ImTextureID
ImTextureStatus
ImU8
ImU16
ImU32
ImU64
ImVec2
ImVec4
ImWchar
ImWchar16
ImWchar32
__builtin_va_list
stbrp_node_im
time_t
va_list

Unions

ImGuiInputEvent__bindgen_ty_1
ImGuiStoragePair__bindgen_ty_1
ImGuiStyleMod__bindgen_ty_1